import { Colors } from './enum';

export enum UserCertificationMode {
  /**
   * 法人认证
   */
  LegalPerson = 10,
  /**
   * 代理人认证
   */
  ProxyPerson = 20,
  /**
   * 后台管理员认证
   */
  AdminCertification = 30,
}

export const UserCertificationModeText = {
  [UserCertificationMode.LegalPerson]: '法人认证',
  [UserCertificationMode.ProxyPerson]: '代理人认证',
};

export enum UserCertificationInvoiceType {
  /**
   * 不开发票
   */
  NotNeedInvoice = 0,
  /**
   * 电子普票
   */
  Electronic = 10,
  /**
   * 电子专票
   */
  EVATInvoice = 20,
}

export const UserCertificationInvoiceTypeText = {
  [UserCertificationInvoiceType.NotNeedInvoice]: '不开发票',
  [UserCertificationInvoiceType.Electronic]: '电子普票',
  [UserCertificationInvoiceType.EVATInvoice]: '电子专票',
};

export enum UserCertificationStatus {
  /**
   * 未认证
   */
  NotCertified = 0,
  /**
   * 已认证
   */
  Certified = 20,
  /**
   * 已过期
   */
  Expired = 30,
}

export enum UserCertificationAuditStatus {
  /**
   * 待支付
   */
  WaitPay = 0,
  /**
   * 待审核
   */
  PendingReview = 10,
  /**
   * 审核通过
   */
  Pass = 30,
  /**
   * 驳回
   */
  Reject = 40,
}

/**
 * 用于前端展现的status
 */
export enum UserCertificationFrontStatus {
  /**
   * 未认证
   */
  NotCertified = 0,
  /**
   * 待支付
   */
  WaitPay = 1,
  /**
   * 认证审核中
   */
  Processing = 10,
  /**
   * 已认证
   */
  Certified = 20,
  /**
   * 已过期
   */
  Expired = 30,
  /**
   * 认证失败
   */
  Rejected = -10,
}

export const UserCertificationStatusConvertFrontStatusMap = {
  [UserCertificationStatus.NotCertified]: UserCertificationFrontStatus.NotCertified,
  [UserCertificationStatus.Certified]: UserCertificationFrontStatus.Certified,
  [UserCertificationStatus.Expired]: UserCertificationFrontStatus.Expired,
};

export const UserCertificationAuditStatusConvertFrontStatusMap = {
  [UserCertificationAuditStatus.WaitPay]: UserCertificationFrontStatus.WaitPay,
  [UserCertificationAuditStatus.PendingReview]: UserCertificationFrontStatus.Processing,
  [UserCertificationAuditStatus.Reject]: UserCertificationFrontStatus.Rejected,
};

export const UserCertificationFrontStatusText = {
  [UserCertificationFrontStatus.Processing]: '认证审核中',
  [UserCertificationFrontStatus.Certified]: '已认证',
  [UserCertificationFrontStatus.Rejected]: '审核未通过',
  [UserCertificationFrontStatus.NotCertified]: '未认证',
  [UserCertificationFrontStatus.Expired]: '已过期',
  [UserCertificationFrontStatus.WaitPay]: '待支付',
};

export const UserCertificationFrontStatusColor = {
  [UserCertificationFrontStatus.Processing]: Colors.Warning,
  [UserCertificationFrontStatus.Certified]: Colors.Success,
  [UserCertificationFrontStatus.Rejected]: Colors.Danger,
  [UserCertificationFrontStatus.NotCertified]: Colors.Danger,
  [UserCertificationFrontStatus.Expired]: Colors.Danger,
  [UserCertificationFrontStatus.WaitPay]: Colors.Warning,
};

export enum UserCertificationInvoicingStatus {
  /**
   * 无需开票
   */
  NotNeedInvoice = 0,
  /**
   * 待开具
   */
  PendingInvoice = 10,
  /**
   * 已开票
   */
  Invoiced = 20,
}

export enum UserCertificationPayType {
  /**
   * 支付宝
   */
  AliPay = 10,
  /**
   * 微信
   */
  WxPay = 20,
  /**
   * 线下支付
   */
  OfflinePay = 30,
  /**
   * 无需支付
   */
  NotNeedPay = 40,
}

export const UserCertificationPayTypeText = {
  [UserCertificationPayType.AliPay]: '支付宝',
  [UserCertificationPayType.WxPay]: '微信',
  [UserCertificationPayType.OfflinePay]: '线下支付',
};

export enum PayCreditedStatus {
  /**
   * 待入账
   */
  WaitCredited = 10,
  /**
   * 已入账
   */
  Credited = 20,
  /**
   * 未支付
   */
  NotCredited = 30,
}

export const PayCreditedStatusText = {
  [PayCreditedStatus.WaitCredited]: '待入账',
  [PayCreditedStatus.Credited]: '已入账',
  [PayCreditedStatus.NotCredited]: '未支付',
};
